@@ -491,7 +491,7 @@
 #define HAVE_PROTOTYPE_STD__ISNAN 1
 
 /* Define if your system has a prototype for fpclassf in math.h */
-#define HAVE_PROTOTYPE__FPCLASSF 1
+/* #undef HAVE_PROTOTYPE__FPCLASSF */
 
 /* Define if your system has a prototype for listen in sys/types.h
   sys/socket.h */
